package com.supervision.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.lang.Pair;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.supervision.dto.roundAsk.SessionParamDTO;
import com.supervision.exception.BusinessException;
import com.supervision.service.AskService;
import com.supervision.vo.*;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.*;

import java.util.*;

import static com.supervision.service.impl.AskServiceImpl.SESSION_PARAM;

@Slf4j
@RestController
@RequestMapping("ask")
@RequiredArgsConstructor
public class AskController {

    private final AskService askService;

    private final RedisTemplate<String, Object> redisTemplate;

    @ApiOperation("多轮对话")
    @PostMapping("roundTalk")
    public RoundTalkResVO roundTalk(@RequestBody RoundTalkReqVO roundTalkReqVO) {
        if (StrUtil.isBlank(roundTalkReqVO.getSessionId())) {
            throw new BusinessException("会话ID不能为空");
        }
        try {
            return askService.roundTalk(roundTalkReqVO);
        } catch (Exception e) {
            log.error("多轮对话过程中出现了异常,则说明多轮对话走不通,那么就根据sessionId获取Redis中的原始问题,直接走单轮对话", e);
            // 如果多轮对话过程中出现了异常,则说明多轮对话走不通,那么就根据sessionId获取Redis中的原始问题,直接走单轮对话
            SingleTalkResVO singleTalkResVO = askService.singleTalk(SingleTalkReqVO.builder().userTalk(roundTalkReqVO.getUserTalk()).build());
            return RoundTalkResVO.builder().sessionId(roundTalkReqVO.getSessionId())
                    .answerText(singleTalkResVO.getAnswerText()).build();
        }

    }

    @ApiOperation("单轮对话")
    @PostMapping("singleTalk")
    public SingleTalkResVO singleTalk(@RequestBody SingleTalkReqVO singleTalkReqVO) {
        log.info("单轮对话问题开始:{}", singleTalkReqVO.getUserTalk());
        try {
            SingleTalkResVO singleTalkResVO = askService.singleTalk(singleTalkReqVO);
            log.info("单轮对话问题结束:{}", singleTalkReqVO.getUserTalk());
            return singleTalkResVO;
        } catch (Exception e) {
            log.error("单轮对话过程中出现了异常", e);
            return SingleTalkResVO.builder().answerText("您好,我暂时还不会回答这个问题哦!").build();
        }

    }

    @ApiOperation("多轮对话中用户手动填写参数,返回唯一的角色设置ID")
    @PostMapping("saveUserParam")
    public String saveUserParam(@RequestBody List<RoleSetNode> paramList) {
        return askService.saveUserParam(paramList);
    }

    @ApiOperation("查询多轮对话中用户需要填写的参数以及回答的码表")
    @GetMapping("queryUserNeedParam")
    public Map<Pair<String, String>, List<Pair<Integer, String>>> queryUserNeedParam() {
        return askService.queryUserNeedParam();
    }
}
