package com.supervision.enums;

import cn.hutool.core.collection.CollUtil;

import java.util.ArrayList;
import java.util.List;

public enum IdentifyIntentEnum {
    业务的受理条件("业务的受理条件", "process_condition", "process_condition_edge", CollUtil.newArrayList("事项办理的要求或限制，例如，年龄，职业，缴费年限要求等")),
    业务的办理流程("业务的办理流程", "handler_process", "handler_process_edge", CollUtil.newArrayList("一般指办理事项的流程是什么？比如先后顺序等")),
    业务的材料清单("业务的材料清单", "checklist", "checklist_edge", CollUtil.newArrayList("询问办理事项需要登记的业务材料，如申领表；或办理事项需要的个人凭证，如身份证、户口本等")),
    业务的受理范围("业务的受理范围", "accept_scope", "accept_scope_edge", CollUtil.newArrayList("适用政策的人群范围，比如什么人群才能办理")),
    业务的办理途径("业务的办理途径", "handler_channel", "handler_channel_edge", CollUtil.newArrayList("一般指询问是否支持线上办理以及是否支持线下办理")),
    业务的办理窗口("业务的办理窗口", "handler_place", "handler_place_edge", CollUtil.newArrayList("线下办理具体地点，属性包括服务窗口名称，地点、电话、办理时间，位置指引"));

    private final String intent;

    private final String tagType;

    private final String edgeType;

    private final List<String> explainList;

    IdentifyIntentEnum(String intent, String tagType, String edgeType, List<String> explainList) {
        this.intent = intent;
        this.tagType = tagType;
        this.edgeType = edgeType;
        this.explainList = explainList;
    }

    public static IdentifyIntentEnum getEnumByIntent(String intent) {
        for (IdentifyIntentEnum value : IdentifyIntentEnum.values()) {
            if (value.getIntent().equals(intent)) {
                return value;
            }
        }
        return null;
    }

    public String getEdgeType() {
        return edgeType;
    }

    public String getTagType() {
        return tagType;
    }

    public String getIntent() {
        return intent;
    }

    public List<String> getExplainList() {
        return explainList;
    }
}
