package com.supervision.handler.gpt;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONUtil;
import com.supervision.ai.AiUtil;
import com.supervision.ai.dto.MessageDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Slf4j
@Component
public class AnswerQuestionHandler {

    public String answerQuestion(String question, List<String> detailList, Map<String, String> talkRecord) {
        String template = "作为AI助手，你的任务是帮助用户查找和理解特定政务的政策内容并给于用户答案。在这个场景中，你将使用政策内容来回答用户问题：{}。请根据政策内容\n" +
                "\"\"\"{}\"\"\"\n" +
                "同时,有一个和用户的问答过程的记录供你参考以提供更精确的回答,内容是:" +
                "\"\"\"{}\"\"\"\n" +
                "请用不超过 100 个词的长度准确和详细的回答用户的问题。注意别让用户知道这个政策文档。回答一定要忠于原文，简洁但不丢信息，不要胡乱编造。请直接给我最终答案,不要反问";
        String askRecordTemplate = "问:{}\n 用户答:{};\n";
        StringBuilder askRecord = new StringBuilder();
        for (Map.Entry<String, String> entry : talkRecord.entrySet()) {
            askRecord.append(StrUtil.format(askRecordTemplate, entry.getKey(), entry.getValue()));
        }
        List<MessageDTO> messageList = new ArrayList<>();
        messageList.add(new MessageDTO("user", StrUtil.format(template, question, JSONUtil.toJsonStr(detailList), askRecord.toString())));

        log.info("多轮问答answerQuestion的prompt是:{}", JSONUtil.toJsonStr(messageList));
        String answer = AiUtil.chatByMessage(messageList);
        log.info("多轮问答answerQuestion的答案是:{}", answer);
        return answer;
    }

    /**
     * 采用了新的提示词方案,好像比之前的那个要好一点
     */
    public String answerSingleQuestionNew(String question, Map<String, List<String>> detailMap) {
        String template = "作为AI助手，你的任务是帮助用户查找和理解特定政务的政策内容并给于用户答案。在这个场景中，你将使用政策内容来回答用户问题：{}。请根据政策内容\n" +
                "\"\"\"{}\"\"\"\n" +
                "并用不超过 100 个词的长度准确和详细的回答用户的问题。注意别让用户知道这个政策文档。回答一定要忠于原文，简洁但不丢信息，不要胡乱编造。请直接给我最终答案,不要反问";
        List<MessageDTO> messageList = new ArrayList<>();
        messageList.add(new MessageDTO("user", StrUtil.format(template, question, JSONUtil.toJsonStr(detailMap))));

        log.info("单轮问答answerQuestion的prompt是:{}", JSONUtil.toJsonStr(messageList));
        String answer = AiUtil.chatByMessage(messageList);
        log.info("单轮问答answerQuestion的答案是:{}", answer);
        return answer;
    }
}
